/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                TERCER GRADO DE PRIMARIA (Excale 03)
/*
/*                        **** HISTORIA ****
/*
/*                 Ciclo escolar evaluado: 2005 - 2006
/*_____________________________________________________________________________
/*
/*
/*    PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE LA ASIGNATURA DE
/*                       HISTORIA EN FORMATO SAS
/*
/*_____________________________________________________________________________
/*
/*  El programa convierte el archivo Excale03_2006_Alum_Hist.txt el cual est en
/*  formato ASCII a una base de datos en formato SAS. La sintxis realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas varibles
/*   - Lectura de variables del archivo en formato ASCII
/*   - Declara los valores perdidos por el usuario (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale03_2006_Alum_Hist.txt
/*         as como el archivo Excale03_2006_Alum_Hist.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE.
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la libreria y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se crear la base de datos (tabla de datos) Excale03_2006_Alum_Hist.sas7bdat.
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale03_2006_Alum_Hist.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS carge los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE ELABORACIN: 9 DE OCTUBRE DE 2007
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum "C:\***\Excale03_2006_Alum_Hist.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbanas Pblicas"
                       2         ="Rurales Pblicas"
                       3         ="Educacin Indgena"
                       4         ="Cursos Comunitarios"
                       5         ="Privadas"
                       6         ="Generales"
                       7         ="Tcnicas"
                       8         ="Telesecundarias"
                       9         ="Privadas";
     VALUE  $modF      "UP"      ="Urbanas Pblicas"
                       "RP"      ="Rurales Pblicas"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privadas"
                       "GRAL"    ="Generales"
                       "TEC"     ="Tcnicas"
                       "TV"      ="Telesecundarias"
                       "PRIV"    ="Privadas";
     VALUE $entestdomF "999999"  ="Respuesta omitida";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadcF
                       1         ="Ocho aos o menos"
                       2         ="Nueve aos"
                       3         ="Diez aos"
                       4         ="Once aos o ms"
                       9         ="Respuesta omitida";
     VALUE edad1sF     1         ="Menos de Ocho aos"
                       2         ="Ocho aos"
                       3         ="Nueve aos"
                       4         ="Diez aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE docenteF    99999     ="Respuesta omitida";
     VALUE RespF       0         ="Fallo"
                       1         ="Acierto"
                       5         ="Reactivo no alcanzado (se considera como no administrado)"
                       7         ="Reactivo no administrado";
RUN;



DATA INEE.Excale03_2006_Alum_Hist;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $20
       id_mod             3
       mod                $4
       entest             $6
       entestdom          $6
       alumno             6
       id_instr           $16
       sexo               3
       edad               8
       edadc              3
       edad1sep           8
       edad1sepc          3
       edadn              3
       edad_ac            3
       mes_nac            3
       w_alu              8
       docente            5
       pha_01             3
       pha_02             3
       pha_03             3
       pha_04             3
       pha_05             3
       pha_06             3
       pha_07             3
       pha_08             3
       phb_01             3
       phb_02             3
       phb_03             3
       phb_04             3
       phb_05             3
       phb_06             3
       phb_07             3
       phb_08             3
       phc_01             3
       phc_02             3
       phc_03             3
       phc_04             3
       phc_05             3
       phc_06             3
       phc_07             3
       phd_01             3
       phd_02             3
       phd_03             3
       phd_04             3
       phd_05             3
       phd_06             3
       phd_07             3
       phe_01             3
       phe_02             3
       phe_03             3
       phe_04             3
       phe_05             3
       phe_06             3
       phe_07             3
       phf_01             3
       phf_02             3
       phf_03             3
       phf_04             3
       phf_05             3
       phf_06             3
       phf_08             3
       phg_01             3
       phg_02             3
       phg_03             3
       phg_04             3
       phg_05             3
       phg_06             3
       phg_07             3
       phg_08             3
       pv1his             8
       pv2his             8
       pv3his             8
       pv4his             8
       pv5his             8
       hisnvl1            3
       hisnvl2            3
       hisnvl3            3
       hisnvl4            3
       hisnvl5            3
       hisnvlb1           3
       hisnvlb2           3
       hisnvlb3           3
       hisnvlb4           3
       hisnvlb5           3
       wvarstrr           3
       w_fstr1            8
       w_fstr2            8
       w_fstr3            8
       w_fstr4            8
       w_fstr5            8
       w_fstr6            8
       w_fstr7            8
       w_fstr8            8
       w_fstr9            8
       w_fstr10           8
       w_fstr11           8
       w_fstr12           8
       w_fstr13           8
       w_fstr14           8
       w_fstr15           8
       w_fstr16           8
       w_fstr17           8
       w_fstr18           8
       w_fstr19           8
       w_fstr20           8
       w_fstr21           8
       w_fstr22           8
       w_fstr23           8
       w_fstr24           8
       w_fstr25           8
       w_fstr26           8
       w_fstr27           8
       w_fstr28           8
       w_fstr29           8
       w_fstr30           8
       w_fstr31           8
       w_fstr32           8
       w_fstr33           8
       w_fstr34           8
       w_fstr35           8
       w_fstr36           8
       w_fstr37           8
       w_fstr38           8
       w_fstr39           8
       w_fstr40           8
       w_fstr41           8
       w_fstr42           8
       w_fstr43           8
       w_fstr44           8
       w_fstr45           8
       w_fstr46           8
       w_fstr47           8
       w_fstr48           8
       w_fstr49           8
       w_fstr50           8
       w_fstr51           8
       w_fstr52           8
       w_fstr53           8
       w_fstr54           8
       w_fstr55           8
       w_fstr56           8
       w_fstr57           8
       w_fstr58           8
       w_fstr59           8
       w_fstr60           8
       w_fstr61           8
       w_fstr62           8
       w_fstr63           8
       w_fstr64           8
       w_fstr65           8
       w_fstr66           8
       w_fstr67           8
       w_fstr68           8
       w_fstr69           8
       w_fstr70           8
       w_fstr71           8
       w_fstr72           8
       w_fstr73           8
       w_fstr74           8
       w_fstr75           8
       w_fstr76           8
       w_fstr77           8
       w_fstr78           8
       w_fstr79           8
       w_fstr80           8
   ;

INFILE alum MISSOVER LINESIZE = 1382;
   INPUT
       nacional              1 - 1
       escuela               2 - 5
       id_ent                6 - 7
       nom_ent               8 - 27
       id_mod               28 - 28
       mod                  29 - 32
       entest               33 - 38
       entestdom            39 - 44
       alumno               45 - 50
       id_instr             51 - 66
       sexo                 67 - 67
       edad                 68 - 72
       edadc                73 - 73
       edad1sep             74 - 89
       edad1sepc            90 - 92
       edadn                93 - 93
       edad_ac              94 - 95
       mes_nac              96 - 97
       w_alu                98 - 113
       docente             114 - 118
       pha_01              119 - 119
       pha_02              120 - 120
       pha_03              121 - 121
       pha_04              122 - 122
       pha_05              123 - 123
       pha_06              124 - 124
       pha_07              125 - 125
       pha_08              126 - 126
       phb_01              127 - 127
       phb_02              128 - 128
       phb_03              129 - 129
       phb_04              130 - 130
       phb_05              131 - 131
       phb_06              132 - 132
       phb_07              133 - 133
       phb_08              134 - 134
       phc_01              135 - 135
       phc_02              136 - 136
       phc_03              137 - 137
       phc_04              138 - 138
       phc_05              139 - 139
       phc_06              140 - 140
       phc_07              141 - 141
       phd_01              142 - 142
       phd_02              143 - 143
       phd_03              144 - 144
       phd_04              145 - 145
       phd_05              146 - 146
       phd_06              147 - 147
       phd_07              148 - 148
       phe_01              149 - 149
       phe_02              150 - 150
       phe_03              151 - 151
       phe_04              152 - 152
       phe_05              153 - 153
       phe_06              154 - 154
       phe_07              155 - 155
       phf_01              156 - 156
       phf_02              157 - 157
       phf_03              158 - 158
       phf_04              159 - 159
       phf_05              160 - 160
       phf_06              161 - 161
       phf_08              162 - 162
       phg_01              163 - 163
       phg_02              164 - 164
       phg_03              165 - 165
       phg_04              166 - 166
       phg_05              167 - 167
       phg_06              168 - 168
       phg_07              169 - 169
       phg_08              170 - 170
       pv1his              171 - 186
       pv2his              187 - 202
       pv3his              203 - 218
       pv4his              219 - 234
       pv5his              235 - 250
       hisnvl1             251 - 251
       hisnvl2             252 - 252
       hisnvl3             253 - 253
       hisnvl4             254 - 254
       hisnvl5             255 - 255
       hisnvlb1            256 - 256
       hisnvlb2            257 - 257
       hisnvlb3            258 - 258
       hisnvlb4            259 - 259
       hisnvlb5            260 - 260
       wvarstrr            261 - 262
       w_fstr1             263 - 276
       w_fstr2             277 - 290
       w_fstr3             291 - 304
       w_fstr4             305 - 318
       w_fstr5             319 - 332
       w_fstr6             333 - 346
       w_fstr7             347 - 360
       w_fstr8             361 - 374
       w_fstr9             375 - 388
       w_fstr10            389 - 402
       w_fstr11            403 - 416
       w_fstr12            417 - 430
       w_fstr13            431 - 444
       w_fstr14            445 - 458
       w_fstr15            459 - 472
       w_fstr16            473 - 486
       w_fstr17            487 - 500
       w_fstr18            501 - 514
       w_fstr19            515 - 528
       w_fstr20            529 - 542
       w_fstr21            543 - 556
       w_fstr22            557 - 570
       w_fstr23            571 - 584
       w_fstr24            585 - 598
       w_fstr25            599 - 612
       w_fstr26            613 - 626
       w_fstr27            627 - 640
       w_fstr28            641 - 654
       w_fstr29            655 - 668
       w_fstr30            669 - 682
       w_fstr31            683 - 696
       w_fstr32            697 - 710
       w_fstr33            711 - 724
       w_fstr34            725 - 738
       w_fstr35            739 - 752
       w_fstr36            753 - 766
       w_fstr37            767 - 780
       w_fstr38            781 - 794
       w_fstr39            795 - 808
       w_fstr40            809 - 822
       w_fstr41            823 - 836
       w_fstr42            837 - 850
       w_fstr43            851 - 864
       w_fstr44            865 - 878
       w_fstr45            879 - 892
       w_fstr46            893 - 906
       w_fstr47            907 - 920
       w_fstr48            921 - 934
       w_fstr49            935 - 948
       w_fstr50            949 - 962
       w_fstr51            963 - 976
       w_fstr52            977 - 990
       w_fstr53            991 - 1004
       w_fstr54           1005 - 1018
       w_fstr55           1019 - 1032
       w_fstr56           1033 - 1046
       w_fstr57           1047 - 1060
       w_fstr58           1061 - 1074
       w_fstr59           1075 - 1088
       w_fstr60           1089 - 1102
       w_fstr61           1103 - 1116
       w_fstr62           1117 - 1130
       w_fstr63           1131 - 1144
       w_fstr64           1145 - 1158
       w_fstr65           1159 - 1172
       w_fstr66           1173 - 1186
       w_fstr67           1187 - 1200
       w_fstr68           1201 - 1214
       w_fstr69           1215 - 1228
       w_fstr70           1229 - 1242
       w_fstr71           1243 - 1256
       w_fstr72           1257 - 1270
       w_fstr73           1271 - 1284
       w_fstr74           1285 - 1298
       w_fstr75           1299 - 1312
       w_fstr76           1313 - 1326
       w_fstr77           1327 - 1340
       w_fstr78           1341 - 1354
       w_fstr79           1355 - 1368
       w_fstr80           1369 - 1382
   ;

   LABEL
       nacional    = "Variable auxiliar para obtener promedios nacionales"
       escuela     = "Identificador de la escuela"
       id_ent      = "Entidad federativa (identificador numrico)"
       nom_ent     = "Entidad federativa"
       id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       mod         = "Estrato escolar o Modalidad educativa"
       entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       entestdom   = "Variable auxiliar para identificar los dominios de estudio (subpoblaciones donde se reportan resultados) a nivel de modalidad al interior de las entidades"
       alumno      = "Identifcador del alumno"
       id_instr    = "Identificador del cuadernillo de examen"
       sexo        = "Sexo del alumno"
       edad        = "Edad del alumno al mes de mayo de 2006, en aos (al momento de la aplicacin)"
       edadc       = "Edad del alumno al mes de mayo de 2006, codificada (al momento de la aplicacin)"
       edad1sep    = "Edad del alumno al mes de septiembre de 2005, en aos (al inicio del ciclo escolar)"
       edad1sepc   = "Edad del alumno al mes de septiembre de 2005, codificada (al inicio del ciclo escolar)"
       edadn       = "Edad normativa"
       edad_ac     = "Edad en aos cumplidos (al momento de la aplicacin)"
       mes_nac     = "Mes de nacimiento del alumno (al momento de la aplicacin)"
       w_alu       = "Peso muestral o ponderador del alumno"
       docente     = "Identificador del docente que imparte clases al alumno"
       pha_01      = "Reactivo PHA_01. Utilizar documentos para elaborar la historia personal"
       pha_02      = "Reactivo PHA_02. Identificar las principales actividades de la poca prehispnica"
       pha_03      = "Reactivo PHA_03. Reconocer las causas de los principales acontecimientos en la poca prehispnica"
       pha_04      = "Reactivo PHA_04. Reconocer el origen de los primeros pobladores de Amrica"
       pha_05      = "Reactivo PHA_05. Reconocer los principales personajes del Descubrimiento y la Conquista de Mxico"
       pha_06      = "Reactivo PHA_06. Reconocer el periodo histrico conocido como Porfiriato"
       pha_07      = "Reactivo PHA_07. Reconocer la duracin del Porfiriato"
       pha_08      = "Reactivo PHA_08. Identificar los principales personajes de la Revolucin Mexicana"
       phb_01      = "Reactivo PHB_01. Identificar los cambios en los objetos debido al paso del tiempo"
       phb_02      = "Reactivo PHB_02. Identificar la forma en que los primeros pobladores de Amrica satisfacieron sus necesidades"
       phb_03      = "Reactivo PHB_03. Reconocer las causas del Descubrimiento"
       phb_04      = "Reactivo PHB_04. Reconocer los motivos de los espaoles para conquistar Mxico"
       phb_05      = "Reactivo PHB_05. Identificar las principales actividades econmicas de la Colonia"
       phb_06      = "Reactivo PHB_06. Reconocer el periodo histrico de la Revolucin Mexicana"
       phb_07      = "Reactivo PHB_07. Identificar al presidente e institucin involucrados en la elaboracin de la Constitucin de 1917"
       phb_08      = "Reactivo PHB_08. Reconocer el hecho histrico conocido como migracin"
       phc_01      = "Reactivo PHC_01. Ubicar a la poca prehispnica en una lnea del tiempo"
       phc_02      = "Reactivo PHC_02. Identificar el acontecimiento histrico del descubrimiento de Amrica"
       phc_03      = "Reactivo PHC_03. Identificar el concepto histrico conocido como mestizaje"
       phc_04      = "Reactivo PHC_04. Identificar las caractersticas de los grupos polticos  liberal y conservador"
       phc_05      = "Reactivo PHC_05. Reconocer las causas que provocaron las intervenciones extranjeras en la primera dcada de la Repblica y sus consecuencias"
       phc_06      = "Reactivo PHC_06. Identificar las principales caractersticas del Porfiriato: ferrocarril y medios de comunicacin"
       phc_07      = "Reactivo PHC_07. Identificar las principales caractersticas del Porfiriato: industrializacin"
       phd_01      = "Reactivo PHD_01. Ubicar al Virreinato en la lnea del tiempo"
       phd_02      = "Reactivo PHD_02. Reconocer el periodo histrico conocido como Colonia"
       phd_03      = "Reactivo PHD_03. Identificar las principales caractersticas del Porfiriato: servicios pblicos"
       phd_04      = "Reactivo PHD_04. Identificar las principales caractersticas del Porfiriato: desigualdad social"
       phd_05      = "Reactivo PHD_05. Distinguir relaciones de parentesco en el rbol genealgico"
       phd_06      = "Reactivo PHD_06. Identificar los principales acontecimientos en la primera dcada de la Repblica"
       phd_07      = "Reactivo PHD_07. Reconocer las causas polticas que provocaron la Revolucin Mexicana"
       phe_01      = "Reactivo PHE_01. Identificar las medidas del tiempo: das, semanas, meses, aos, lustros, dcadas o siglos en la lnea del tiempo"
       phe_02      = "Reactivo PHE_02. Identificar los elementos de la organizacin social en la Colonia"
       phe_03      = "Reactivo PHE_03. Reconocer el hecho histrico conocido como  Independencia"
       phe_04      = "Reactivo PHE_04. Reconocer el periodo histrico conocido como consumacin de la Independencia"
       phe_05      = "Reactivo PHE_05. Reconocer las causas econmicas que provocaron la Revolucin Mexicana"
       phe_06      = "Reactivo PHE_06. Identificar los cambios en la forma de vida cotidiana desde la antigedad a la vida contempornea"
       phe_07      = "Reactivo PHE_07. Ubicar los principales periodos de la historia en una lnea del tiempo"
       phf_01      = "Reactivo PHF_01. Reconocer los dilogos que sirven como testimonio oral para elaborar la historia personal"
       phf_02      = "Reactivo PHF_02. Identificar los cambios que suceden en la forma de vida a travs del tiempo"
       phf_03      = "Reactivo PHF_03. Identificar los conceptos histricos conocidos como nomadismo y sedentarismo"
       phf_04      = "Reactivo PHF_04. Identificar principales personajes de la Independencia"
       phf_05      = "Reactivo PHF_05. Identificar hechos caractersticos del inicio de la independencia"
       phf_06      = "Reactivo PHF_06. Reconocer los principales personajes de la primera dcada de la Repblica"
       phf_08      = "Reactivo PHF_08. Identificar los conceptos: urbano y rural"
       phg_01      = "Reactivo PHG_01. Ubicar la Independencia de Mxico en la lnea del tiempo"
       phg_02      = "Reactivo PHG_02. Identificar fuentes documentales y testimonios orales relativos a la historia personal"
       phg_03      = "Reactivo PHG_03. Conocer el hecho histrico conocido como Conquista"
       phg_04      = "Reactivo PHG_04. Identificar los elementos de la organizacin poltica en la Colonia"
       phg_05      = "Reactivo PHG_05. Identificar condiciones de los esclavos en la Colonia"
       phg_06      = "Reactivo PHG_06. Reconocer las causas sociales que provocaron la Revolucin Mexicana"
       phg_07      = "Reactivo PHG_07. Reconocer el hecho histrico conocido como industrializacin"
       phg_08      = "Reactivo PHG_08. Identificar los cambios en el transporte en el Mxico contemporneo"
       pv1his      = "Primer valor plausible de Educacin Cvica"
       pv2his      = "Segundo valor plausible de Educacin Cvica"
       pv3his      = "Tercer valor plausible de Educacin Cvica"
       pv4his      = "Cuarto valor plausible de Educacin Cvica"
       pv5his      = "Quinto valor plausible de Educacin Cvica"
       hisnvl1     = "Nivel de logro en Educacin Cvica. Asociado a pv1civ. (Cuatro niveles)"
       hisnvl2     = "Nivel de logro en Educacin Cvica. Asociado a pv2civ. (Cuatro niveles)"
       hisnvl3     = "Nivel de logro en Educacin Cvica. Asociado a pv3civ. (Cuatro niveles)"
       hisnvl4     = "Nivel de logro en Educacin Cvica. Asociado a pv4civ. (Cuatro niveles)"
       hisnvl5     = "Nivel de logro en Educacin Cvica. Asociado a pv5civ. (Cuatro niveles)"
       hisnvlb1    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Educacin Cvica. Asociado a pv1civ."
       hisnvlb2    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Educacin Cvica. Asociado a pv2civ."
       hisnvlb3    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Educacin Cvica. Asociado a pv3civ."
       hisnvlb4    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Educacin Cvica. Asociado a pv4civ."
       hisnvlb5    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Educacin Cvica. Asociado a pv5civ."
       wvarstrr    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       w_fstr1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
   ;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char20.
       id_mod             id_modF.
       mod                $modF.
       entest             $char6.
       entestdom          $entestdomF.
       alumno             6.
       id_instr           $char16.
       sexo               sexoF.
       edadc              edadcF.
       edad1sepc          edad1sF.
       edadn              edadnF.
       edad_ac            edad_acF.
       mes_nac            mes_nacF.
       docente            docenteF.
       pha_01             RespF.
       pha_02             RespF.
       pha_03             RespF.
       pha_04             RespF.
       pha_05             RespF.
       pha_06             RespF.
       pha_07             RespF.
       pha_08             RespF.
       phb_01             RespF.
       phb_02             RespF.
       phb_03             RespF.
       phb_04             RespF.
       phb_05             RespF.
       phb_06             RespF.
       phb_07             RespF.
       phb_08             RespF.
       phc_01             RespF.
       phc_02             RespF.
       phc_03             RespF.
       phc_04             RespF.
       phc_05             RespF.
       phc_06             RespF.
       phc_07             RespF.
       phd_01             RespF.
       phd_02             RespF.
       phd_03             RespF.
       phd_04             RespF.
       phd_05             RespF.
       phd_06             RespF.
       phd_07             RespF.
       phe_01             RespF.
       phe_02             RespF.
       phe_03             RespF.
       phe_04             RespF.
       phe_05             RespF.
       phe_06             RespF.
       phe_07             RespF.
       phf_01             RespF.
       phf_02             RespF.
       phf_03             RespF.
       phf_04             RespF.
       phf_05             RespF.
       phf_06             RespF.
       phf_08             RespF.
       phg_01             RespF.
       phg_02             RespF.
       phg_03             RespF.
       phg_04             RespF.
       phg_05             RespF.
       phg_06             RespF.
       phg_07             RespF.
       phg_08             RespF.
       hisnvl1            1.
       hisnvl2            1.
       hisnvl3            1.
       hisnvl4            1.
       hisnvl5            1.
       hisnvlb1           1.
       hisnvlb2           1.
       hisnvlb3           1.
       hisnvlb4           1.
       hisnvlb5           1.
       wvarstrr           2.
   ;
/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Multiple.
/*   .S o S = No contestado.
/*************************************************************************/
   IF entestdom = "999999"  THEN entestdom = "S";
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;

   ARRAY perdidos1(4)  sexo edadc edad1sepc edadn;
   DO  i=1 TO 4;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(4)  edad edad1sep edad_ac mes_nac;
   DO  i=1 TO 4;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(52)
                   pha_01 pha_02 pha_03 pha_04 pha_05 pha_06 pha_07 pha_08
                   phb_01 phb_02 phb_03 phb_04 phb_05 phb_06 phb_07 phb_08
                   phc_01 phc_02 phc_03 phc_04 phc_05 phc_06 phc_07 phd_01
                   phd_02 phd_03 phd_04 phd_05 phd_06 phd_07 phe_01 phe_02
                   phe_03 phe_04 phe_05 phe_06 phe_07 phf_01 phf_02 phf_03
                   phf_04 phf_05 phf_06 phf_08 phg_01 phg_02 phg_03 phg_04
                   phg_05 phg_06 phg_07 phg_08;
   DO  i=1 TO 52;
          IF (perdidos3{i} = 5 OR  perdidos3{i} = 7)  THEN  perdidos3{i} = .N;
   END;

   drop i;
RUN;
